yakumo.neutron.v2.floating_ip.Resource

Package yakumo :: Package neutron :: Package v2 :: Module floating_ip :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

       object --+
                |
    base.Resource --+
                    |
                   Resource

Resource class for floating IPs in Networking V2 API

Instance Methods | [hide private]
None |
update(self, floating_ip=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) Update a floting IP address | source code
None |
associate(self, port=None) Associate a floting IP address with a port | source code
None |
disassociate(self) Disassociate a floting IP address | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, floating_ip=`'``__UNDEF__``'`, port=`'``__UNDEF__``'`) | source code
Update a floting IP address Parameters: `floating_ip` (str) - Floating IP address `port` (yakumo.neutron.v2.port) - Port Returns: None Overrides: base.Resource.update

### associate(self, port=None) | source code
Associate a floting IP address with a port Parameters: `port` (yakumo.neutron.v2.port) - Port Returns: None